pytilities.types.sequencetype — Pytilities 1.2.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities 1.2.0 documentation »
- API documentation »
- pytilities »
- pytilities.types »

# pytilities.types.sequencetype

class `pytilities.types.sequencetype.` `SequenceType`

  Represents any ordered sequence.

  A sequence supports indexed access (i.e., [] access, __getitem__, ...).

  Lists and tuples are subtypes of this type.

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities 1.2.0 documentation »
- API documentation »
- pytilities »
- pytilities.types »